@@ -7,13 +7,14 @@
 
 #pragma once
 
-#include <glib.h>
+#include <gio/gio.h>
 
 #define FU_EFIVAR_GUID_EFI_GLOBAL			"8be4df61-93ca-11d2-aa0d-00e098032b8c"
 #define FU_EFIVAR_GUID_FWUPDATE				"0abba7dc-e516-4167-bbf5-4d9d1c739416"
 #define FU_EFIVAR_GUID_UX_CAPSULE			"3b8c8162-188c-46a4-aec9-be43f1d65697"
 #define FU_EFIVAR_GUID_SECURITY_DATABASE		"d719b2cb-3d3a-4596-a3bc-dad00e67656f"
 #define FU_EFIVAR_GUID_UX_CAPSULE			"3b8c8162-188c-46a4-aec9-be43f1d65697"
+#define FU_EFIVAR_GUID_EFI_CAPSULE_REPORT		"39b68c46-f7fb-441b-b6ec-16b0f69821f3"
 
 #define FU_EFIVAR_ATTR_NON_VOLATILE			(1 << 0)
 #define FU_EFIVAR_ATTR_BOOTSERVICE_ACCESS		(1 << 1)
@@ -27,6 +28,9 @@ gboolean	 fu_efivar_supported		(GError		**error);
 guint64		 fu_efivar_space_used		(GError		**error);
 gboolean	 fu_efivar_exists		(const gchar	*guid,
 						 const gchar	*name);
+GFileMonitor	*fu_efivar_get_monitor		(const gchar	*guid,
+						 const gchar	*name,
+						 GError		**error);
 gboolean	 fu_efivar_get_data		(const gchar	*guid,
 						 const gchar	*name,
 						 guint8		**data,
